Models
======

.. automodule:: astrophot.models
   :members:
   :undoc-members:
   :show-inheritance:

Sky Models
----------

.. automodule:: astrophot.models.flatsky
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: astrophot.models.planesky
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: astrophot.models.bilinear_sky
   :members:
   :undoc-members:
   :show-inheritance:

Point Source Models
-------------------

.. automodule:: astrophot.models.point_source
   :members:
   :undoc-members:
   :show-inheritance:

Galaxy Models
-------------

.. automodule:: astrophot.models.radial
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: astrophot.models.edgeon
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: astrophot.models.gaussian_ellipsoid
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: astrophot.models.multi_gaussian_expansion
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: astrophot.models.pixelated_model
   :members:
   :undoc-members:
   :show-inheritance:

PSF Models
----------

.. automodule:: astrophot.models.radial_psf
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: astrophot.models.airy
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: astrophot.models.pixelated_psf
   :members:
   :undoc-members:
   :show-inheritance:

Model Mixins
------------

.. automodule:: astrophot.models.mixins
   :members:
   :undoc-members:
   :show-inheritance:
